==> Task-Catalyst-Tutorial-0.01.tar.gz: Task-Catalyst-Tutorial-0.01/lib/Task/Catalyst/Tutorial.pm <==
package Task::Catalyst::Tutorial;

use warnings;
use strict;

=head1 NAME

Task::Catalyst::Tutorial - Installs everything you need to learn Catalyst

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

Installs the L<Catalyst::Manual::Tutorial|Catalyst::Manual::Tutorial>
PODs, the example "MyApp", and all dependencies.


=head1 AUTHOR

The Catalyst Team 

L<http://www.catalystframework.org>.

=head1 MAINTAINER

Jonathan Rockway C<< <jrockway@cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to
C<bug-task-catalyst-tutorial at rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Task-Catalyst-Tutorial>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Task::Catalyst::Tutorial

You can also look for information at:

=over 4

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Task-Catalyst-Tutorial>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Task-Catalyst-Tutorial>

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Task-Catalyst-Tutorial>

=item * Search CPAN

L<http://search.cpan.org/dist/Task-Catalyst-Tutorial>

=back

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2006 Jonathan Rockway, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Task::Catalyst::Tutorial

==> Task-Catalyst-Tutorial-0.03.tar.gz: Task-Catalyst-Tutorial-0.03/lib/Task/Catalyst/Tutorial.pm <==
package Task::Catalyst::Tutorial;

use warnings;
use strict;

=head1 NAME

Task::Catalyst::Tutorial - Installs everything you need to learn Catalyst

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.03';

=head1 SYNOPSIS

Installs the example "MyApp" described in
L<Catalyst::Manual::Tutorial>, and all its dependencies.

=head1 AUTHOR

The Catalyst Team 

L<http://www.catalystframework.org>.

=head1 MAINTAINER

Jonathan Rockway C<< <jrockway@cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to
C<bug-task-catalyst-tutorial at rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Task-Catalyst-Tutorial>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Task::Catalyst::Tutorial

You can also look for information at:

=over 4

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Task-Catalyst-Tutorial>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Task-Catalyst-Tutorial>

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Task-Catalyst-Tutorial>

=item * Search CPAN

L<http://search.cpan.org/dist/Task-Catalyst-Tutorial>

=back

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2006 Jonathan Rockway, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Task::Catalyst::Tutorial
